﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace _3458A_DINT_Visa32cs
{
    class Program
    {
        static void Main(string[] args)
        {
            int RM;
            int DMM;
            string id;
            byte[] byteid = new byte[100];
            visa32.viOpenDefaultRM(out RM);
            visa32.viOpen(RM, "GPIB0::22::INSTR", visa32.VI_NULL, 20000, out DMM);



            visa32.viPrintf(DMM,"END ALWAYS\n");   //Set endline termination so you can retrieve data from instrument
            visa32.viPrintf(DMM,"ID?\n");  // Identify Instrument and print to screen
            visa32.viScanf(DMM,"%t",byteid);
            id = Encoding.ASCII.GetString(byteid);

            Console.WriteLine("Instrument Identity String: " + id);


            //Turn off memory, take data directly over bus
            visa32.viPrintf(DMM,"MEM OFF\n");


            // Specify DATA FORMAT
            visa32.viPrintf(DMM,"MFORMAT DINT\n");
            visa32.viPrintf(DMM,"OFORMAT DINT\n");

            //Configure the instrument

            visa32.viPrintf(DMM,"DCV 10\n");
            visa32.viPrintf(DMM,"TRIG AUTO\n");
            visa32.viPrintf(DMM,"NRDGS 5\n");  //Set number of readings per trigger to desired value
            visa32.viPrintf(DMM,"NPLC 1\n"); //Set desired number of NPLCs, increase for greater accuracy

            visa32.viPrintf(DMM,"ISCALE?\n");  //Get scale value so you can convert DINT data

            double scale = 0;
            string scalestring;


            visa32.viRead(DMM, out scalestring,100);
            scale = double.Parse(scalestring);//Convert string result to double

            visa32.viPrintf(DMM,"END ON\n");  //Have to use END ON with multiple readings
            visa32.viPrintf(DMM,"TARM SGL\n"); //Triggers the instrument 1 time then becomes hold

            
            byte[] rawdata = new byte[22];  //size should be at least nrdgs*4 +2
            double[] scaleddata = new double[5];   //size should be at least nrdgs

            //Read the DINT data
            visa32.viScanf(DMM,"%5ly", rawdata);  // nrdgs*4 + 2

            
        
            //Convert the DINT reading data and scale it with ISCALE then output to screen
             for (int i = 0; i < 5; i++)
             {
                 
                 scaleddata[i] = System.BitConverter.ToInt32(rawdata, (i*4)) * scale;  //converting 4 byte readings by scaling factor
                 Console.WriteLine(scaleddata[i]);
             }
             
           
             
            

            Console.WriteLine("Measurement Finished\n");

            Console.WriteLine("Press any key to close...");
            Console.ReadLine();
             


            visa32.viClose(DMM);
            visa32.viClose(RM);
        }
    }
}
